@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.47 2003/01/22 07:46:05 arvind Exp $
+ $Id: battstat_applet.c,v 1.49 2003/03/12 17:15:11 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -743,9 +743,10 @@ help_cb (BonoboUIComponent *uic,
 {
     GError *error = NULL;
 
-    egg_screen_help_display (
+    egg_help_display_on_screen (
+		"battstat", NULL,
 		gtk_widget_get_screen (battstat->applet),
-		"battstat", NULL, &error);
+		&error);
 
     if (error) { /* FIXME: the user needs to see this */
         g_warning ("help error: %s\n", error->message);
@@ -851,7 +852,7 @@ about_cb (BonoboUIComponent *uic,
 				_("Battery Charge Monitor"), 
 				VERSION,
 				_("(C) 2000 The Gnulix Society, (C) 2002 Free Software Foundation"),
-				_("This utility show the status of your laptop battery."),
+				_("This utility shows the status of your laptop battery."),
 				authors,
 				documenters,
 				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
