@@ -38,6 +38,8 @@ typedef struct
 	GtkWidget   *hbox;
 	GtkWidget   *eyes[MAX_EYES];
 	guint        timeout_id;
+	gint pointer_last_x;
+	gint pointer_last_y;
 
 	/* Theme */
 	GdkPixbuf *eye_image;
@@ -71,7 +73,7 @@ void load_theme    (EyesApplet        *eyes_applet,
 		    const gchar       *theme_dir);
 
 void properties_cb (BonoboUIComponent *uic,
-		    gpointer           user_data,
+		    EyesApplet        *eyes_applet,
 		    const gchar       *verbname);
 
 #endif
