@@ -114,8 +114,6 @@ gkb_draw (GKB * gkb)
 
 }
 
-
-#define GKB_SMALL_PANEL_SIZE 25	/* less than */
 /**
  * count_sizes:
  * @gkb:
@@ -677,9 +675,10 @@ help_cb (BonoboUIComponent *uic,
 {
 	GError *error = NULL;
 
-	egg_screen_help_display (
+	egg_help_display_on_screen (
+			"gkb", NULL,
 			gtk_widget_get_screen (gkb->applet),
-			"gkb", NULL, &error);
+			&error);
 
 	/* FIXME: display error to the user */
 }
@@ -799,18 +798,12 @@ static const BonoboUIVerb gkb_menu_verbs [] = {
 	BONOBO_UI_VERB_END
 };
 
-static void gkb_destroy (GtkWidget * widget, gpointer data) {
-	gchar *cmd;
+static void gkb_destroy (GtkWidget * widget, gpointer data)
+{
 	GKB *gkb = (GKB *)data;
-
-	/* restore the default keymap before exiting */
-	cmd = g_strdup_printf ("xmodmap %s/.gkb_default.xmm", g_get_home_dir ());
-	system (cmd);
-	g_free (cmd);
 	
 	if (gkb->propwindow)
 		gtk_widget_destroy (gkb->propwindow);
-	gkb_update_handlers (gkb, TRUE);
 	g_free(gkb);
 }
 
