@@ -88,6 +88,7 @@ tree_create (GtkTreeStore *model)
   column = gtk_tree_view_column_new_with_attributes (_("Keyboards (select and press add)"), cell,
                                                            "text", 0, NULL);
 
+  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tree1), FALSE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree1), column);
  
   while ((sets = g_list_next (sets)) != NULL)
@@ -288,17 +289,49 @@ preadd_cb (GtkTreeSelection *selection,
   return;
 }
 
+static gboolean
+comparefunc (GkbKeymap *k1, GkbKeymap *k2)
+{
+  if ((k1->name && k2->name) && (k1->country && k2->country))
+    return (strcmp (k1->name, k2->name) || strcmp (k1->country, k2->country));
+}
 
 static gint
 addwadd_cb (GtkWidget * addbutton, GkbPropertyBoxInfo * pbi)
 {
   GkbKeymap *tdata;
+  GtkWidget *dialog;
+  GKB * gkb = pbi->gkb;
   /* Do not add Language and Country rows */
 
   if (pbi->keymap_for_add) 
    {
    if (pbi->keymap_for_add->command != NULL)
     {
+      if (g_list_find_custom (pbi->keymaps, pbi->keymap_for_add, (GCompareFunc) comparefunc) != NULL)
+        { 
+          GtkWidget *dialog = NULL ; 
+          gchar *str;
+          str = _("Keymap `%s' for the country %s already exists");
+
+          dialog = gtk_message_dialog_new (GTK_WINDOW (gkb->addwindow),
+					   GTK_DIALOG_DESTROY_WITH_PARENT,
+					   GTK_MESSAGE_INFO,
+					   GTK_BUTTONS_OK,
+			                   str,
+					   pbi->keymap_for_add->name,
+					   pbi->keymap_for_add->country);
+
+          g_signal_connect_swapped (GTK_OBJECT (dialog),
+				    "response",
+				    G_CALLBACK (gtk_widget_destroy),
+				    GTK_OBJECT (dialog));
+
+          gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+          gtk_widget_show (dialog);
+          return FALSE;
+        }
+
       tdata = g_new0 (GkbKeymap, 1);
 
       tdata->name = g_strdup (pbi->keymap_for_add->name);
@@ -378,6 +411,7 @@ gkb_prop_map_add (GkbPropertyBoxInfo * pbi)
   GtkWidget *tree1;
   GtkWidget *button;
   GtkWidget *scrolled1;
+  GtkWidget *label;
   GtkTreeSelection *selection;
   GKB *gkb = pbi->gkb;
  
@@ -399,6 +433,7 @@ gkb_prop_map_add (GkbPropertyBoxInfo * pbi)
   gtk_widget_set_sensitive (button, FALSE);
   
   gtk_dialog_set_default_response (GTK_DIALOG (gkb->addwindow), 100);
+  gtk_dialog_set_has_separator (GTK_DIALOG (gkb->addwindow), FALSE);
   gtk_window_set_screen (GTK_WINDOW (gkb->addwindow),
 			 gtk_widget_get_screen (gkb->applet));
   gtk_object_set_data (GTK_OBJECT (gkb->addwindow), "addwindow",
@@ -406,9 +441,17 @@ gkb_prop_map_add (GkbPropertyBoxInfo * pbi)
   gtk_object_set_data (GTK_OBJECT (gkb->addwindow), "addbutton",
 		       button);
   
-  vbox1 = GTK_DIALOG (gkb->addwindow)->vbox;
+  vbox1 = gtk_vbox_new (FALSE, 6); 
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (gkb->addwindow)->vbox), vbox1, FALSE, FALSE, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
   gtk_widget_show (vbox1);
   
+  label = gtk_label_new_with_mnemonic (_("_Keyboards (select and press add):"));
+  gtk_box_pack_start (GTK_BOX (vbox1), label, FALSE, FALSE, 0);
+  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_widget_show (label);
+  
   scrolled1 = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled1),
 				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -421,6 +464,7 @@ gkb_prop_map_add (GkbPropertyBoxInfo * pbi)
                G_TYPE_STRING, G_TYPE_STRING); 
 
   tree1 = tree_create (pbi->model);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), tree1);
 
   gtk_widget_show (tree1);
 
