@@ -390,9 +390,8 @@ gkb_prop_create_buttons_vbox (GkbPropertyBoxInfo * pbi)
   GtkWidget *vbox;
 
   vbox = gtk_vbutton_box_new ();
-  gtk_button_box_set_spacing (GTK_BUTTON_BOX (vbox), 4);
-  gtk_button_box_set_child_size (GTK_BUTTON_BOX (vbox), 75, 25);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
+  gtk_button_box_set_spacing (GTK_BUTTON_BOX (vbox), 6);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), 0);
   gtk_button_box_set_layout (GTK_BUTTON_BOX (vbox), GTK_BUTTONBOX_START);
       
   pbi->buttons_vbox = vbox;
@@ -440,7 +439,7 @@ gkb_prop_list_load_keymaps (GkbPropertyBoxInfo * pbi)
  * Return Value: 
  **/
 GtkWidget *
-gkb_prop_create_scrolled_window (GkbPropertyBoxInfo * pbi)
+gkb_prop_create_scrolled_window (GkbPropertyBoxInfo * pbi, GtkWidget *label)
 {
   GtkWidget *scrolled_window;
   GtkTreeModel *model;
@@ -456,6 +455,7 @@ gkb_prop_create_scrolled_window (GkbPropertyBoxInfo * pbi)
   store = gtk_list_store_new (3, GDK_TYPE_PIXBUF, G_TYPE_STRING,G_TYPE_POINTER);	
   model = GTK_TREE_MODEL(store);	
   treeview = gtk_tree_view_new_with_model (model);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), treeview);
   GTK_WIDGET_SET_FLAGS (treeview, GTK_CAN_DEFAULT);
     
   pbi->list = GTK_TREE_VIEW (treeview);
