@@ -67,21 +67,40 @@ static void
 gkb_prop_map_close_clicked (GkbMapDialogInfo * mdi)
 {
   GkbKeymap *keymap;
+  gchar *name, *label, *command, *flag;
                                                                                 
   keymap = mdi->keymap;
                                                                                 
-  gkb_keymap_free_internals (keymap);
-                                                                                
-  keymap->name = g_strdup (gtk_entry_get_text (GTK_ENTRY (mdi->name_entry)));
-  keymap->label =
+  name = g_strdup (gtk_entry_get_text (GTK_ENTRY (mdi->name_entry)));
+  if (name) {
+  	 if  (keymap->name)
+  		g_free (keymap->name);
+  	keymap->name = name;
+  }
+  label =
     g_strdup (gtk_entry_get_text (GTK_ENTRY (mdi->label_entry)));
-  keymap->command =
+  if (label) {
+  	 if  (keymap->label)
+  		g_free (keymap->label);
+  	keymap->label = label;
+  }
+  command =
     g_strdup (gtk_entry_get_text (GTK_ENTRY (mdi->command_entry)));
-  keymap->flag =
+  if (command) {
+  	 if  (keymap->command)
+  		g_free (keymap->command);
+  	keymap->command = command;
+  }
+  flag =
     g_strdup (g_basename
               (gnome_icon_entry_get_filename
                (GNOME_ICON_ENTRY (mdi->flag_entry))));
-                                                                                
+  if (flag) {
+  	 if  (keymap->flag)
+  		g_free (keymap->flag);
+  	keymap->flag = flag;
+  }
+                                                                              
   mdi->pbi->selected_keymap = keymap;
                                                                                 
   gkb_prop_list_reload (mdi->pbi);
@@ -106,9 +125,10 @@ gkb_prop_map_help_clicked (GkbMapDialogInfo * mdi)
 {
 	GError *error = NULL;
 
-        egg_screen_help_display (
+        egg_help_display_on_screen (
+		"gkb", "gkb-edit-layout",
   		gtk_window_get_screen (GTK_WINDOW (mdi->dialog)),
-		"gkb", "gkb-edit-layout", &error);
+		&error);
 
 	/* FIXME: display error to the user */
 }
@@ -131,8 +151,9 @@ gkb_prop_map_label_at (GtkWidget * table, gint row, gint col,
 		    row, row + 1, col, col + 1,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (label_prop_map), GTK_JUSTIFY_RIGHT);
-  gtk_misc_set_alignment (GTK_MISC (label_prop_map), 1, 0.5);
+  gtk_label_set_justify (GTK_LABEL (label_prop_map), GTK_JUSTIFY_LEFT);
+  gtk_misc_set_alignment (GTK_MISC (label_prop_map), 0.0, 0.5);
+  gtk_label_set_use_markup (GTK_LABEL (label_prop_map), TRUE);
 }
 
 /**
@@ -161,6 +182,43 @@ gkb_prop_map_entry_at (GtkWidget * table, gint row, gint col,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
 
+  gtk_label_set_mnemonic_widget( GTK_LABEL(label_prop_map), entry);
+  gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
+  if (gail_loaded)
+    {
+      add_atk_relation(entry, label_prop_map, ATK_RELATION_LABELLED_BY);
+    }
+  return entry;
+}
+
+/**
+ * gkb_prop_map_icon_entry_at:
+ * @table: 
+ * @row: 
+ * @col: 
+ * @entry_text: 
+ * 
+ * Create an icon entry and add it to a table at a specified position
+ * 
+ * Return Value: 
+ **/
+static GtkWidget *
+gkb_prop_map_icon_entry_at (GtkWidget * table, gint row, gint col,
+                            GkbMapDialogInfo * mdi, const gchar * entry_text)
+{
+  GtkWidget *entry;
+  GtkWidget *hbox;
+  
+  hbox = gtk_hbox_new (FALSE, 0);
+  entry = gnome_icon_entry_new (NULL, NULL);
+ 
+  gtk_table_attach (GTK_TABLE (table), hbox,
+		    row, row + 1, col, col + 1,
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (GTK_FILL), 0, 0);
+ 
+  gtk_box_pack_start (GTK_BOX (hbox), entry, FALSE, FALSE, 0);
+
   gtk_label_set_mnemonic_widget( GTK_LABEL(label_prop_map), entry);
   if (gail_loaded)
     {
@@ -190,12 +248,8 @@ void
 gkb_prop_map_edit (GkbPropertyBoxInfo * pbi)
 {
   GkbMapDialogInfo *mdi;
-  GtkWidget *vbox2;
+  GtkWidget *vbox1;
   GtkWidget *table1;
-  GtkWidget *hbox1;
-  GtkWidget *label4;
-  GtkWidget *frame1;
-  GtkWidget *label5;
   GkbKeymap *keymap;
 
   if (pbi->selected_keymap == NULL)
@@ -213,24 +267,29 @@ gkb_prop_map_edit (GkbPropertyBoxInfo * pbi)
   mdi->dialog = gtk_dialog_new_with_buttons (_("Edit Keyboard"), NULL,
   				GTK_DIALOG_DESTROY_WITH_PARENT,
   				GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-  				GTK_STOCK_OK, GTK_RESPONSE_OK,
+  				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
   				NULL);
 
-  gtk_window_set_transient_for (mdi->dialog, pbi->box);
+  gtk_window_set_transient_for (GTK_WINDOW (mdi->dialog), GTK_WINDOW (pbi->box));
   gtk_window_set_modal (GTK_WINDOW (mdi->dialog), TRUE);
 
-  vbox2 = gtk_vbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (mdi->dialog)->vbox), vbox2,
+  gtk_dialog_set_has_separator (GTK_DIALOG (mdi->dialog), FALSE);
+  gtk_dialog_set_default_response (GTK_DIALOG (mdi->dialog), GTK_RESPONSE_CLOSE);
+  gtk_window_set_resizable (GTK_WINDOW (mdi->dialog), FALSE);
+
+  vbox1 = gtk_vbox_new (FALSE, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (mdi->dialog)->vbox), vbox1,
                         TRUE, TRUE, 0);
 
-  table1 = gtk_table_new (3, 2, FALSE);
-  gtk_box_pack_start (GTK_BOX (vbox2), table1, TRUE, TRUE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (table1), 3);
-  gtk_table_set_row_spacings (GTK_TABLE (table1), 3);
-  gtk_table_set_col_spacings (GTK_TABLE (table1), 3);
+  table1 = gtk_table_new (4, 2, FALSE);
+  gtk_box_pack_start (GTK_BOX (vbox1), table1, TRUE, TRUE, 0);
+  gtk_table_set_row_spacings (GTK_TABLE (table1), 6);
+  gtk_table_set_col_spacings (GTK_TABLE (table1), 12);
 
   gkb_prop_map_label_at (table1, 0, 0, _("_Name:"));
   mdi->name_entry = gkb_prop_map_entry_at (table1, 1, 0, mdi, keymap->name);
+  gtk_widget_set_size_request (mdi->name_entry, 225, -1);
 
   gkb_prop_map_label_at (table1, 0, 1, _("_Label:"));
   mdi->label_entry = gkb_prop_map_entry_at (table1, 1, 1, mdi, keymap->label);
@@ -238,56 +297,25 @@ gkb_prop_map_edit (GkbPropertyBoxInfo * pbi)
   gkb_prop_map_label_at (table1, 0, 2, _("Co_mmand:"));
   mdi->command_entry = gkb_prop_map_entry_at (table1, 1, 2, mdi, keymap->command);
 
+  gkb_prop_map_label_at (table1, 0, 3, _("_Flag:"));
+  mdi->flag_entry = gkb_prop_map_icon_entry_at (table1, 1, 3, mdi, keymap->flag);
+
+  gnome_icon_entry_set_pixmap_subdir (GNOME_ICON_ENTRY (mdi->flag_entry), "gkb");
+  gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (mdi->flag_entry), keymap->flag);
+
   gtk_widget_show_all (table1);
 
-  hbox1 = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox2), hbox1, TRUE, TRUE, 0);
-
-  label4 = gtk_label_new (_("Where command can be:\n * xmodmap /full/path/xmodmap.hu\n * gkb_xmmap hu\n * setxkbmap hu"));
-  gtk_widget_show (label4);
-  gtk_box_pack_start (GTK_BOX (hbox1), label4, FALSE, FALSE, 0);
-  gtk_label_set_justify (GTK_LABEL (label4), GTK_JUSTIFY_LEFT);
-  gtk_misc_set_padding (GTK_MISC (label4), 5, 0);
-
-  if (gail_loaded)
-   {
-     add_atk_relation(label4, mdi->command_entry, ATK_RELATION_LABEL_FOR);
-     add_atk_relation(mdi->command_entry, label4, ATK_RELATION_LABELLED_BY);
-   }
-
-  frame1 = gtk_frame_new (NULL);
-  gtk_widget_show (frame1);
-  gtk_box_pack_start (GTK_BOX (hbox1), frame1, TRUE, TRUE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (frame1), 3);
-
-  mdi->flag_entry = gnome_icon_entry_new (NULL, NULL);
-  gnome_icon_entry_set_pixmap_subdir (GNOME_ICON_ENTRY (mdi->flag_entry), "gkb");
-
-  gtk_widget_show (mdi->flag_entry);
-  gtk_container_add (GTK_CONTAINER (frame1), mdi->flag_entry);
-  gtk_container_set_border_width (GTK_CONTAINER (mdi->flag_entry), 5);
-
-  gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (mdi->flag_entry), keymap->flag);
-  
   if (gail_loaded)
    {
       add_atk_relation(mdi->flag_entry, label_prop_map, ATK_RELATION_LABELLED_BY);
       add_atk_relation(label_prop_map, mdi->flag_entry, ATK_RELATION_LABEL_FOR);
    }
                                                               
-
-  label5 = gtk_label_new_with_mnemonic (_("_Flag"));
-  gtk_widget_show (label5);
-  gtk_frame_set_label_widget (GTK_FRAME (frame1), label5);
-  gtk_label_set_justify (GTK_LABEL (label5), GTK_JUSTIFY_LEFT);
-
   g_signal_connect (G_OBJECT (mdi->dialog), "response",
                     G_CALLBACK (window_response),
                     mdi);
 
-  gtk_widget_show_all (hbox1);
-
-  gtk_widget_show_all (vbox2);
+  gtk_widget_show_all (vbox1);
 
   /* Go, go go !! */
   gtk_widget_show_all (mdi->dialog);
