@@ -27,6 +27,7 @@
 
 #include "modemlights.h"
 #include <panel-applet.h>
+#include <egg-screen-help.h>
 #include "digits.xpm"
 
 #include <stdlib.h>
@@ -186,7 +187,9 @@ static DisplayData *layout_current = NULL;
 
 static gint setup_done = FALSE;
 
-static void about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+static void about_cb (BonoboUIComponent *uic,
+		      PanelApplet       *applet,
+		      const gchar       *verbname)
 {
 	static GtkWidget *about = NULL;
 	GdkPixbuf 	 *pixbuf;
@@ -205,10 +208,10 @@ static void about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbna
 
 	const gchar *translator_credits = _("translator_credits");
 
-	if (about != NULL)
-	{
-		gdk_window_show(about->window);
-		gdk_window_raise(about->window);
+	if (about) {
+		gtk_window_set_screen (GTK_WINDOW (about),
+				       gtk_widget_get_screen (GTK_WIDGET (applet)));
+		gtk_window_present (GTK_WINDOW (about));
 		return;
 	}
 
@@ -234,12 +237,12 @@ static void about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbna
 	if (pixbuf)
 		gdk_pixbuf_unref (pixbuf);
 
+	gtk_window_set_screen (GTK_WINDOW (about),
+			       gtk_widget_get_screen (GTK_WIDGET (applet)));
 	gtk_window_set_wmclass (GTK_WINDOW (about), "modem lights", "Modem Lights");
 	gtk_signal_connect( GTK_OBJECT(about), "destroy",
 			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
 	gtk_widget_show (about);
-	return;
-	data = NULL;
 }
 
 static int is_Modem_on(void)
@@ -1231,7 +1234,7 @@ static void update_pixmaps(void)
 		{
 		GdkGC *mask_gc = NULL;
 
-		button_mask = gdk_pixmap_new(NULL, 10, 10, 1);
+		button_mask = gdk_pixmap_new(display_area->window, 10, 10, 1);
 
 		mask_gc = gdk_gc_new(button_mask);
 
@@ -1415,15 +1418,20 @@ button_press_hack (GtkWidget      *widget,
 }
 
 
-static void show_help_cb(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+static void show_help_cb (BonoboUIComponent *uic,
+			  PanelApplet       *applet,
+			  const char        *verbname)
 {
-	gnome_help_display ("modemlights_applet", NULL, NULL);
+	egg_help_display_on_screen (
+		"modemlights_applet", NULL,
+		gtk_widget_get_screen (GTK_WIDGET (applet)),
+		NULL);
 }
 
 static const BonoboUIVerb modem_applet_menu_verbs [] = {
-        BONOBO_UI_VERB ("Props", property_show),
-        BONOBO_UI_VERB ("Help", show_help_cb),
-        BONOBO_UI_VERB ("About", about_cb),
+        BONOBO_UI_UNSAFE_VERB ("Props", property_show),
+        BONOBO_UI_UNSAFE_VERB ("Help", show_help_cb),
+        BONOBO_UI_UNSAFE_VERB ("About", about_cb),
 
         BONOBO_UI_VERB_END
 };
