@@ -233,15 +233,14 @@ static void box_color_cb(GnomeColorPicker *cp, guint nopr, guint nopg, guint nop
 static GtkWidget *box_add_color(PanelApplet *applet, GtkWidget *box, 
 				const gchar *text, ColorType color)
 {
-	GtkWidget *vbox;
+	GtkWidget *hbox;
 	GtkWidget *label;
 	GtkWidget *color_sel;
 	GdkColor c;
 
-	vbox = gtk_vbox_new(FALSE, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox), 0);
-	gtk_box_pack_start(GTK_BOX(box), vbox, TRUE, TRUE, 0);
-	gtk_widget_show(vbox);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX(box), hbox, FALSE, FALSE, 0);
+	gtk_widget_show (hbox);
 
 	if (display_color_text[color] != NULL)
 		{
@@ -252,53 +251,92 @@ static GtkWidget *box_add_color(PanelApplet *applet, GtkWidget *box,
 		c.red = c.green = c.blue = 0;
 		}
 
+	label = gtk_label_new_with_mnemonic (text);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
+
 	color_sel = gnome_color_picker_new();
 	gnome_color_picker_set_use_alpha(GNOME_COLOR_PICKER(color_sel), FALSE);
 	gnome_color_picker_set_i16(GNOME_COLOR_PICKER(color_sel), c.red, c.green, c.blue, 0);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_sel);
 	g_signal_connect(G_OBJECT(color_sel), "color_set", 
 			 G_CALLBACK (box_color_cb), GINT_TO_POINTER((gint)color));
-	g_object_set_data(G_OBJECT(color_sel), "applet", applet);
-	gtk_box_pack_start(GTK_BOX(vbox), color_sel, FALSE, FALSE, 0);
+	g_object_set_data (G_OBJECT (color_sel), "applet", applet);
+	gtk_box_pack_start(GTK_BOX(hbox), color_sel, FALSE, FALSE, 0);
 	gtk_widget_show(color_sel);
 
-	label = gtk_label_new_with_mnemonic(text);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_sel);
-	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
-	gtk_widget_show(label);
+	return label;
+}
 
-	return vbox;
+static GtkWidget *create_hig_category (GtkWidget *main_box, gchar *title)
+{
+	GtkWidget *vbox, *vbox2, *hbox;
+	GtkWidget *label;
+	gchar *tmp;
+		
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (main_box), vbox, FALSE, FALSE, 0);
+	
+	tmp = g_strdup_printf ("<b>%s</b>", title);
+	label = gtk_label_new (NULL);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_label_set_markup (GTK_LABEL (label), tmp);
+	g_free (tmp);
+	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
+
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+	
+	label = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	
+	vbox2 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
+
+	return vbox2;	
 }
 
 static GtkWidget *color_frame_new(GtkWidget *vbox, const gchar *text)
 	{
-	GtkWidget *frame;
+	GtkWidget *category;
 	GtkWidget *hbox;
 
-	frame = gtk_frame_new(text);
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
+	category = create_hig_category (vbox, (gchar *)text);
+	gtk_widget_show (category);
 
-	hbox = gtk_hbox_new(TRUE, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(hbox), GNOME_PAD_SMALL);
-	gtk_container_add(GTK_CONTAINER(frame), hbox);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (category), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
 	return hbox;
 	}
 
 static void
-phelp_cb (GtkWidget *w, gint tab, gpointer data)
+phelp_cb (GtkDialog *dialog)
 {
-#ifdef FIXME /* use (egg|gnome)_screen_help_display */
-	GnomeHelpMenuEntry help_entry = { "modemlights_applet",
-					  "index.html#MODEMLIGHTS-PREFS" };
-	gnome_help_display(NULL, &help_entry);
-#endif
+	GError *error = NULL;
+
+	egg_help_display_on_screen (
+		"modemlights_applet", "modemlights-prefs",
+		gtk_window_get_screen (GTK_WINDOW (dialog)),
+		&error);
+
+	if (error) {
+		g_warning ("help error: %s\n", error->message);
+		g_error_free (error);
+		error = NULL;
+	}
 }
 
 static void
 property_response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
+	if (id == GTK_RESPONSE_HELP) {
+		phelp_cb (dialog);
+		return;
+	}
+	
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 	propwindow = NULL;
 }
@@ -308,15 +346,14 @@ void property_show (BonoboUIComponent *uic,
 		    const gchar       *verbname)
 {
 	GtkWidget *frame;
-	GtkWidget *hbox;
+	GtkWidget *hbox, *hbox2, *hbox3;
 	GtkWidget *notebook;
-	GtkWidget *vbox;
-	GtkWidget *vbox1;
+	GtkWidget *vbox, *vbox2;
 	GtkWidget *label;
 	GtkWidget *delay_w;
 	GtkObject *delay_adj;
 	GtkWidget *checkbox;
-	GtkWidget *button;
+	GtkSizeGroup *size_group;
 
 	if (propwindow) {
 		gtk_window_set_screen (GTK_WINDOW (propwindow),
@@ -327,33 +364,75 @@ void property_show (BonoboUIComponent *uic,
 
         propwindow = gtk_dialog_new_with_buttons (_("Modem Lights Preferences"), NULL,
 						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 						  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 						  NULL);
 	gtk_window_set_screen (GTK_WINDOW (propwindow),
 			       gtk_widget_get_screen (GTK_WIDGET (applet)));
+	gtk_dialog_set_default_response (GTK_DIALOG (propwindow), GTK_RESPONSE_CLOSE);
+  	gtk_dialog_set_has_separator (GTK_DIALOG (propwindow), FALSE);
+	gtk_window_set_resizable (GTK_WINDOW (propwindow), FALSE);
 
 	notebook = gtk_notebook_new ();
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_container_set_border_width (GTK_CONTAINER (notebook), 12);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (propwindow)->vbox), notebook,
 			    TRUE, TRUE, 0);
 	
-	vbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox), GNOME_PAD_SMALL);
+	vbox = gtk_vbox_new (FALSE, 18);
+	gtk_container_set_border_width (GTK_CONTAINER(vbox), 12);
 
-	frame = gtk_frame_new(_("Connecting"));
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
+	frame = create_hig_category (vbox, _("Display"));
 
-	vbox1 = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox1), GNOME_PAD_SMALL);
-	gtk_container_add(GTK_CONTAINER(frame), vbox1);
-	gtk_widget_show(vbox1);
+	/* update adjustment */
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (frame), hbox, FALSE, FALSE, 0);
+	gtk_widget_show (hbox);
+
+        label = gtk_label_new_with_mnemonic (_("U_pdate every:"));
+        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
+
+	delay_adj = gtk_adjustment_new( UPDATE_DELAY, 1.0, 20.0, 1, 1, 1 );
+        delay_w  = gtk_spin_button_new( GTK_ADJUSTMENT(delay_adj), 1, 0 );
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), delay_w);
+	gtk_box_pack_start (GTK_BOX (hbox), delay_w, FALSE, FALSE, 0);
+	g_signal_connect (G_OBJECT (delay_w), "focus-out-event",
+			  G_CALLBACK (update_delay_cb), applet);
+	gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (delay_w),GTK_UPDATE_ALWAYS );
+	gtk_widget_show (delay_w);
+
+	label = gtk_label_new_with_mnemonic (_("seconds"));
+        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
+
+	/* extra info checkbox */
+	checkbox = gtk_check_button_new_with_mnemonic (_("Sho_w connect time and throughput"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), show_extra_info);
+	g_signal_connect (G_OBJECT (checkbox), "toggled",
+			 G_CALLBACK (show_extra_info_cb), applet);
+	gtk_box_pack_start (GTK_BOX (frame), checkbox, FALSE, FALSE, 0);
+	gtk_widget_show (checkbox);
+
+	checkbox = gtk_check_button_new_with_mnemonic (_("B_link connection status when connecting"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), status_wait_blink);
+	g_signal_connect (G_OBJECT (checkbox), "toggled",
+			 G_CALLBACK (wait_blink_cb), applet);
+	gtk_box_pack_start (GTK_BOX (frame), checkbox, FALSE, FALSE, 0);
+	gtk_widget_show (checkbox);
+
+	frame = create_hig_category (vbox, _("Connections"));
+
+	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
 	/* connect entry */
-	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-        gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (frame), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-        label = gtk_label_new_with_mnemonic(_("Co_nnect command:"));
+	label = gtk_label_new_with_mnemonic (_("Co_nnection command:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_size_group_add_widget (size_group, label);
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
@@ -366,12 +445,14 @@ void property_show (BonoboUIComponent *uic,
 	gtk_widget_show(connect_entry);
 
 	/* disconnect entry */
-	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-        gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
+	hbox = gtk_hbox_new(FALSE, 12);
+        gtk_box_pack_start(GTK_BOX(frame), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-        label = gtk_label_new_with_mnemonic(_("_Disconnect command:"));
-        gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+        label = gtk_label_new_with_mnemonic(_("_Disconnection command:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_size_group_add_widget (size_group, label);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
 	disconnect_entry = gtk_entry_new_with_max_length(255);
@@ -387,110 +468,112 @@ void property_show (BonoboUIComponent *uic,
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), ask_for_confirmation);
 	g_signal_connect (G_OBJECT (checkbox), "toggled",
 			  G_CALLBACK (confirm_checkbox_cb), applet);
-        gtk_box_pack_start(GTK_BOX(vbox1), checkbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (frame), checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(checkbox);
 
-	frame = gtk_frame_new(_("Display"));
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
-
-	vbox1 = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox1), GNOME_PAD_SMALL);
-	gtk_container_add(GTK_CONTAINER(frame), vbox1);
-	gtk_widget_show(vbox1);
-
-	/* update adjustment */
-	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-        gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
-
-        label = gtk_label_new_with_mnemonic(_("U_pdates per second"));
-        gtk_box_pack_start( GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
-
-	delay_adj = gtk_adjustment_new( UPDATE_DELAY, 1.0, 20.0, 1, 1, 1 );
-        delay_w  = gtk_spin_button_new( GTK_ADJUSTMENT(delay_adj), 1, 0 );
-        gtk_label_set_mnemonic_widget (GTK_LABEL (label), delay_w);
-        gtk_box_pack_start(GTK_BOX(hbox), delay_w, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (delay_w), "focus-out-event",
-			  G_CALLBACK (update_delay_cb), applet);
-        gtk_spin_button_set_update_policy( GTK_SPIN_BUTTON(delay_w),GTK_UPDATE_ALWAYS );
-	gtk_widget_show(delay_w);
-
-	/* extra info checkbox */
-	checkbox = gtk_check_button_new_with_mnemonic(_("Sho_w connect time and throughput"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), show_extra_info);
-	g_signal_connect(G_OBJECT(checkbox), "toggled",
-			 G_CALLBACK(show_extra_info_cb), applet);
-        gtk_box_pack_start(GTK_BOX(vbox1), checkbox, FALSE, FALSE, 0);
-	gtk_widget_show(checkbox);
-
-        label = gtk_label_new(_("General"));
-        gtk_widget_show(vbox);
-        /*gnome_property_box_append_page( GNOME_PROPERTY_BOX(propwindow), vbox, label);*/
+	label = gtk_label_new (_("General"));
+	gtk_widget_show (vbox);
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
 
 	/* color settings */
 
-	vbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox), GNOME_PAD_SMALL);
+	vbox = gtk_vbox_new (FALSE, 18);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
-	hbox = color_frame_new(vbox, _("Receive data"));
+	hbox = color_frame_new (vbox, _("Receive Data"));
+	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-	box_add_color(applet, hbox, _("_Foreground"), COLOR_RX);
-	box_add_color(applet, hbox, _("_Background"), COLOR_RX_BG);
+	hbox2 = gtk_hbox_new (FALSE, 24);
+	gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
 
-	hbox = color_frame_new(vbox, _("Send data"));
+	hbox3 = box_add_color (applet, hbox2, _("_Foreground:"), COLOR_RX);
+	gtk_size_group_add_widget (size_group, hbox3);
+	hbox3 = box_add_color (applet, hbox2, _("_Background:"), COLOR_RX_BG);
+	gtk_size_group_add_widget (size_group, hbox3);
+	
+	hbox = color_frame_new(vbox, _("Send Data"));
+	
+	hbox2 = gtk_hbox_new (FALSE, 24);
+	gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
+	
+	hbox3 = box_add_color (applet, hbox2, _("Foregroun_d:"), COLOR_TX);
+	gtk_size_group_add_widget (size_group, hbox3);
+	hbox3 = box_add_color (applet, hbox2, _("Backg_round:"), COLOR_TX_BG);
+	gtk_size_group_add_widget (size_group, hbox3);
+	
+	hbox = color_frame_new (vbox, _("Connection Status"));
+	
+	vbox2 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox2, FALSE, FALSE, 0);
+	
+	hbox2 = gtk_hbox_new (FALSE, 24);
+	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
+	
+	hbox3 = box_add_color (applet, hbox2, _("Co_nnected:"), COLOR_STATUS_OK);
+	gtk_size_group_add_widget (size_group, hbox3);
+	hbox3 = box_add_color (applet, hbox2, _("Disconnec_ted:"), COLOR_STATUS_BG);
+	gtk_size_group_add_widget (size_group, hbox3);
+		
+	hbox3 = box_add_color (applet, vbox2, _("C_onnecting:"), COLOR_STATUS_WAIT);
+	gtk_size_group_add_widget (size_group, hbox3);
+	
+	hbox = color_frame_new (vbox, _("Text"));
+	
+	vbox2 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox2, FALSE, FALSE, 0);
+	
+	hbox2 = gtk_hbox_new (FALSE, 24);
+	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
+	
+	hbox3 = box_add_color (applet, hbox2, _("For_eground:"), COLOR_TEXT_FG);
+	gtk_size_group_add_widget (size_group, hbox3);
+	hbox3 = box_add_color (applet, hbox2, _("Bac_kground:"), COLOR_TEXT_BG);
+	gtk_size_group_add_widget (size_group, hbox3);
+	hbox3 = box_add_color (applet, vbox2, _("O_utline"), COLOR_TEXT_MID);
+        gtk_size_group_add_widget (size_group, hbox3);
 
-	box_add_color(applet, hbox, _("Foregroun_d"), COLOR_TX);
-	box_add_color(applet, hbox, _("Backg_round"), COLOR_TX_BG);
-
-	hbox = color_frame_new(vbox, _("Connection status"));
-
-	box_add_color(applet, hbox, _("Co_nnected"), COLOR_STATUS_OK);
-	box_add_color(applet, hbox, _("No_t connected"), COLOR_STATUS_BG);
-	vbox1 = box_add_color(applet, hbox, _("A_waiting connection"), COLOR_STATUS_WAIT);
-
-
-	checkbox = gtk_check_button_new_with_mnemonic(_("B_link"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), status_wait_blink);
-	g_signal_connect(G_OBJECT(checkbox), "toggled",
-			 G_CALLBACK(wait_blink_cb), applet);
-        gtk_box_pack_start(GTK_BOX(vbox1), checkbox, FALSE, FALSE, 0);
-	gtk_widget_show(checkbox);
-
-	hbox = color_frame_new(vbox, _("Text"));
-
-	box_add_color(applet, hbox, _("For_eground"), COLOR_TEXT_FG);
-	box_add_color(applet, hbox, _("Bac_kground"), COLOR_TEXT_BG);
-	box_add_color(applet, hbox, _("O_utline"), COLOR_TEXT_MID);
-
-	label = gtk_label_new(_("Colors"));
-	gtk_widget_show(vbox);
-	gtk_notebook_append_page( GTK_NOTEBOOK(notebook), vbox, label);
+	label = gtk_label_new (_("Colors"));
+	gtk_widget_show (vbox);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
 
 	/* advanced settings */
 
-	vbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox), GNOME_PAD_SMALL);
+	vbox = gtk_vbox_new (FALSE, 18);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
-	frame = gtk_frame_new(_("Modem options"));
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
+	frame = create_hig_category (vbox, _("Modem Options"));
 
-	vbox1 = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox1), GNOME_PAD_SMALL);
-	gtk_container_add(GTK_CONTAINER(frame), vbox1);
-	gtk_widget_show(vbox1);
+	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
+	/* device entry */
+	hbox = gtk_hbox_new (FALSE, 12);
+        gtk_box_pack_start (GTK_BOX (frame), hbox, FALSE, FALSE, 0);
+	gtk_widget_show (hbox);
+
+        label = gtk_label_new_with_mnemonic (_("_Device:"));
+	gtk_size_group_add_widget (size_group, label);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
+
+	device_entry = gtk_entry_new_with_max_length (16);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), device_entry);
+	gtk_entry_set_text (GTK_ENTRY (device_entry), device_name);
+	g_signal_connect (G_OBJECT (device_entry), "focus_out_event",
+			  G_CALLBACK (device_changed_cb), applet);
+        gtk_box_pack_start (GTK_BOX (hbox), device_entry, TRUE, TRUE, 0);
+	gtk_widget_show (device_entry);
+	
 	/* lock file entry */
-	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-        gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
+	hbox = gtk_hbox_new(FALSE, 12);
+        gtk_box_pack_start(GTK_BOX(frame), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-        label = gtk_label_new_with_mnemonic(_("_Modem lock file:"));
-        gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+        label = gtk_label_new_with_mnemonic (_("_Lock file:"));
+	gtk_size_group_add_widget (size_group, label);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
 
 	lockfile_entry = gtk_entry_new_with_max_length(255);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), lockfile_entry);
@@ -504,32 +587,15 @@ void property_show (BonoboUIComponent *uic,
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (verify_checkbox), verify_lock_file);
 	g_signal_connect(G_OBJECT(verify_checkbox), "toggled",
 			 G_CALLBACK(verify_lock_file_cb), applet);
-        gtk_box_pack_start(GTK_BOX(vbox1), verify_checkbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (frame), verify_checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(verify_checkbox);
 
-	/* device entry */
-	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-        gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
-
-        label = gtk_label_new_with_mnemonic(_("_Device:"));
-        gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
-
-	device_entry = gtk_entry_new_with_max_length(16);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), device_entry);
-	gtk_entry_set_text(GTK_ENTRY(device_entry), device_name);
-	g_signal_connect (G_OBJECT (device_entry), "focus_out_event",
-			  G_CALLBACK (device_changed_cb), applet);
-        gtk_box_pack_start(GTK_BOX(hbox), device_entry, TRUE, TRUE, 0);
-	gtk_widget_show(device_entry);
-
 	/* ISDN checkbox */
 	checkbox = gtk_check_button_new_with_mnemonic(_("U_se ISDN"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), use_ISDN);
 	g_signal_connect(G_OBJECT(checkbox), "toggled",
 			   G_CALLBACK(isdn_checkbox_cb), applet);
-        gtk_box_pack_start(GTK_BOX(vbox), checkbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (frame), checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(checkbox);
 
 	if (use_ISDN)
@@ -541,8 +607,8 @@ void property_show (BonoboUIComponent *uic,
 #ifdef SHOULD_THIS_BE_HERE
 	/* defaults save button */
 	
-	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-	gtk_box_pack_end(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_end (GTK_BOX (frame), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
 	button = gtk_button_new_with_label(_("Set options as default"));
