@@ -48,8 +48,21 @@ typedef struct
 
 } StickyNotesApplet;
 
+typedef enum
+{
+	STICKYNOTES_NEW = 0,
+	STICKYNOTES_SET_VISIBLE,
+	STICKYNOTES_SET_LOCKED
+
+} StickyNotesDefaultAction;
+
 /* Modify the applet */
-void stickynotes_applet_set_highlighted(StickyNotesApplet *stickynotes, gboolean highlighted);
+void stickynotes_applet_update_icon(StickyNotesApplet *stickynotes, gboolean highlighted);
 void stickynotes_applet_update_tooltips(StickyNotesApplet *stickynotes);
 
+void stickynotes_applet_do_default_action(StickyNotesApplet *stickynotes);
+
+void stickynotes_applet_create_preferences(StickyNotesApplet *stickynotes);
+void stickynotes_applet_create_about(StickyNotesApplet *stickynotes);
+
 #endif /* __STICKYNOTES_APPLET_H__ */
