@@ -23,11 +23,12 @@
 #include <stickynotes.h>
 
 /* Callbacks for the sticky notes windows */
-gboolean window_expose_cb(GtkWidget *widget, GdkEventExpose *event, StickyNote *note);
-gboolean window_delete_cb(GtkWidget *widget, GdkEvent *event, StickyNote *note);
-gboolean window_move_edit_cb(GtkWidget *widget, GdkEventButton *event, StickyNote *note);
+gboolean window_close_cb(GtkWidget *widget, StickyNote *note);
 gboolean window_resize_cb(GtkWidget *widget, GdkEventButton *event, StickyNote *note);
-gboolean window_close_cb(GtkWidget *widget, GdkEventButton *event, StickyNote *note);
+gboolean window_move_cb(GtkWidget *widget, GdkEventButton *event, StickyNote *note);
+gboolean window_expose_cb(GtkWidget *widget, GdkEventExpose *event, StickyNote *note);
+gboolean window_configure_cb(GtkWidget *widget, GdkEventConfigure *event, StickyNote *note);
+gboolean window_delete_cb(GtkWidget *widget, GdkEvent *event, StickyNote *note);
 gboolean window_cross_cb(GtkWidget *widget, GdkEventCrossing *event, StickyNote *note);
 gboolean window_focus_cb(GtkWidget *widget, GdkEventFocus *event, StickyNote *note);
 
